<?php
namespace Ep\Hak;

use Ep\Core\AbstractFactory;
use Ep\WordPress\Settings\SettingsProviderInterface;
use Zend\Stdlib\ArrayUtils;

/**
 * Class ConfigProvider
 *
 * @package Ep\Hak
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-hak
 */
class ConfigProvider implements SettingsProviderInterface
{
	public function __invoke()
	{
		$hakSettings = $this->getDefaults()['ep_hak'];

		if (function_exists('get_option')) {
			$hakSettings = ArrayUtils::merge($hakSettings, get_option('ep_hak', []));
		}

		return [
			'dependencies' => $this->getDependencyConfig(),
			'hak' => $hakSettings,

			'forms' => [
				'settings-hak' => include __DIR__ . '/../forms/settings.php',
				'hak-membership' => include __DIR__ . '/../forms/membership.php',
			],

			'http_clients' => [
				'http.hak' => [
					'base_uri' => $hakSettings['base_uri'],
					'http_errors' => true,
					'headers' => [
						'Content-Type' => 'application/json',
						'Device' => $hakSettings['device'],
						'Username' => $hakSettings['username'],
						'Token' => $hakSettings['token'],
						'Cache-Control' => 'no-cache',
					],
				],
			],

			'wordpress' => [
				'services' => '1' === $hakSettings['enabled'] ? [
					'HakCoupons',
					'HakCart',
					'HakMyAccount',
				] : [],
			],

			'twig' => [
				'paths' => [
					EP_HAK_DIR . '/view',
				],
			],
		];
	}

	public function getDependencyConfig()
	{
		return [
			'aliases' => [
				'Hak' => HakService::class,
				'HakCart' => Service\CartService::class,
				'HakCoupons' => Service\CouponService::class,
				'HakMyAccount' => Service\MyAccountPage::class,
			],

			'factories' => [
				HakService::class => HakServiceFactory::class,
                Service\CartService::class => AbstractFactory::class,
                Service\CouponService::class => AbstractFactory::class,
                Service\MyAccountPage::class => AbstractFactory::class,
			],
		];
	}

	/**
	 * Vraća zadane postavke koje provider pruža.
	 *
	 * @return array
	 */
	public function getDefaults()
	{
		return [
			'ep_hak' => [
				'enabled' => '0',
				'base_uri' => 'https://web2.hak.hr',
				'membership_endpoint' => '/tehnickapomocapi/api/1.0/CheckMemberships',
				'device' => '',
				'username' => '',
				'token' => '',
				'checkButtonLabel' => 'Provjeri!',
				'couponName' => 'HAK popust',
				'discountPercentage' => '',
			],
		];
	}

	/**
	 * Vraća forme za postavke.
	 *
	 * @return array
	 */
	public function getForms()
	{
		return [
			'ep_hak' => 'settings-hak',
		];
	}

	/**
	 * Vraća tabove u control panelu koje ovaj provider definira.
	 *
	 * @return array
	 */
	public function getTabs()
	{
		return [[
			'id' => 'general',
			'optionKeys' => [
				'ep_hak',
			],
		]];
	}
}