<?php
namespace Ep\Hak\Service;

use Ep\Hak\HakService;
use Ep\WordPress\Service\AbstractWordPressService;
use Zend\Form\FormInterface;

/**
 * Class MyAccount
 *
 * @package Ep\Hak\Page
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-hak
 */
class MyAccountPage extends AbstractWordPressService
{
	const ENDPOINT_SLUG = 'hak';

	/**
	 * Kačimo se na WordPress.
	 */
	public function attach(): void
	{
		$config = $this->getConfig('hak');

		if ('1' === $config['enabled']) {
			add_rewrite_endpoint(self::ENDPOINT_SLUG, EP_ROOT | EP_PAGES);
			$renderHook = sprintf('woocommerce_account_%s_endpoint', self::ENDPOINT_SLUG);

			add_filter('woocommerce_account_menu_items', [$this, 'menuItems']);
			add_action($renderHook, [$this, 'renderPage']);
			add_action('user_register', [$this, 'onUserRegister']);
		}
	}

	/**
	 * Povezujemo korisnika s HAK-om prilikom registracije.
	 *
	 * @param $userId
	 */
	public function onUserRegister($userId)
	{
		/** @var HakService $hak */
		$hak = $this->services->get('Hak');
		$hak->connect($userId);
	}

	/**
	 * Dodaje HAK u izbornik na stranici 'Moj račun'.
	 *
	 * @param array $items
	 *
	 * @return array
	 */
	public function menuItems(array $items)
	{
		$items[self::ENDPOINT_SLUG] = 'HAK';
		return $items;
	}

	/**
	 * Renderira stranicu 'Moj Račun'.
	 */
	public function renderPage()
	{
		/** @var FormInterface $form */
		$form = $this->services->get('hak-membership');
		/** @var HakService $hak */
		$hak = $this->services->get('Hak');
		$connected = false;

		if ('POST' === $_SERVER['REQUEST_METHOD']) {
			if (isset($_POST['disconnect'])) {
				$hak->disconnect();
				wc_add_notice('Vaš račun više nije povezan s HAK-om!', 'success');
			} else {
				$form->setData($_POST);

				if ($form->isValid()) {
					$member = $form->getData();

					$hak->setMember([
						'memberId' => $member['hakMemberId'],
						'firstName' => $member['firstName'],
						'lastName' => $member['lastName'],
					]);

					if ($hak->connect()) {
						$connected = true;
						wc_add_notice('Uspješno ste povezali vaš račun s HAK-om!', 'success');
					} else {
						wc_add_notice('Nevažeći broj članske iskaznice.', 'error');
					}
				}
			}
		} else {
			if ($hak->validate()) {
				$connected = true;
				wc_add_notice('Vaš račun je povezan s HAK-om.', 'success');
			} else {
				wc_add_notice('Trenutno niste povezani s HAK-om.', 'error');
			}
		}

		if ($connected || $hak->validate()) {
			$member = $hak->getMember();
			$form->remove('connect');
			$form->setData([
				'hakMemberId' => $member['memberId'],
				'firstName' => $member['firstName'],
				'lastName' => $member['lastName'],
			]);
		} else {
			$form->remove('disconnect');
		}

		ob_start();
		wc_print_notices();
		$notices = ob_get_clean();

		echo $this->getView()->render('hak/my-account.twig', [
			'form' => $form,
			'notices' => $notices,
		]);
	}
}